import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem

ListView {
    id: stackList
    anchors.fill: parent

    model: StackListModel {
         id: stackFeed
         path: "questions"
         query: "$.items[*]"
         limit: 50
         page: 1
         args: "order=desc&sort=activity"
         site: stackView.site
     }

    delegate: ListItem.Subtitled {
        id: stackItemDelegate
        text: model.title
        subText: model.answer_count + " answers    -    Asked by: " + model.owner['display_name']
        iconFrame: true
        icon: UbuntuShape {
                color: model.accepted_answer_id ? "green" : "gray"
                Label{
                    anchors.centerIn: parent
                    fontSize: "large"
                    text: model.score
                    color: "white"
                }
            }
        progression: true
        onClicked: {
           questionViewer.question = model.question_id
           questionViewer.link = model.link
           pageStack.push(questionViewer)
        }
    }
    property bool __dragTriggerMore: false

    onContentYChanged:  {
        if (!stackList.dragging) {
            return
        }

        var drag_down = stackList.contentY
        var drag_up = stackList.height - ((1-stackList.visibleArea.yPosition) * stackList.contentHeight)
        var drag_distance = 0
        if (drag_down < 0) {
            drag_distance = drag_down;
        } else if (drag_up > 0) {
            drag_distance = drag_up;
        }

        // Reset triggers to make sure
        __dragTriggerMore = false

        if (drag_distance > 0) {
            listViewFooter.visible = true;
            if (drag_distance < units.gu(10)) {
                listViewFooter.text = 'Keep dragging to load more...'
                listViewFooter.font.bold = false
            } else {
                listViewFooter.text = 'Release to load more'
                listViewFooter.font.bold = true
                __dragTriggerMore = true
            }
        } else {
            listViewFooter.visible = false;
        }
    }

    onDragEnded:  {
        listViewFooter.visible = false

        if (__dragTriggerMore) {
            stackList.cancelFlick()
            stackFeed.page = stackFeed.page + 1
            stackList.positionViewAtBeginning()
        }
    }
}
