/* JSONListModel - a QML ListModel with JSON and JSONPath support
 *
 * Copyright (c) 2012 Romain Pokrzywka (KDAB) (romain@kdab.com)
 * Licensed under the MIT licence (http://opensource.org/licenses/mit-license.php)
 */

import QtQuick 2.0
import "lib/jsonpath.js" as JSONPath

ListModel {
    property string source: ""
    property string json: ""
    property string query: "$.items[*]"
    property string urlBase: 'http://api.stackexchange.com/2.1/'
    property string path: ""
    property string args: ""
    property string site: ''
    property string token: "QoLg9vB1*QhsBd)6hn5lOQ(("
    property int limit: 0
    property int page: 0

    onUrlBaseChanged: __rebuildSource()
    onSiteChanged: __rebuildSource()
    onPathChanged: __rebuildSource()
    onPageChanged: __rebuildSource()

    function __rebuildSource() {
        var newSource = urlBase + path + "?access_token&key=" + token
        if (args != "") {
            newSource += "&" + args
        }
        if (limit != 0){
            newSource += "&pagesize=" + limit
        }
        if (page != 0) {
            newSource += "&page="+page
        }
        if (site != "") {
            newSource += "&site=" + site
        }
        source = newSource
    }

    onSourceChanged: __loadSource()
    function __loadSource() {
        console.log('Loading: '+source)
        var xhr = new XMLHttpRequest;
        xhr.open("GET", source);
        xhr.onreadystatechange = function() {
            if (xhr.readyState == XMLHttpRequest.DONE)
                json = xhr.responseText;
        }
        xhr.send();

    }

    function reload() {
         __loadSource()
    }

    onJsonChanged: updateJSONModel()
    onQueryChanged: updateJSONModel()

    function updateJSONModel() {
        clear();
        if ( json === "" )
            return;

        var objectArray = parseJSONString(json, query);

        for ( var key in objectArray ) {
            var jo = objectArray[key];
            append( jo );

        }
    }

    function parseJSONString(jsonString, jsonPathQuery) {
        var objectArray = JSON.parse(jsonString);

        if ( jsonPathQuery !== "" ) {
            objectArray = JSONPath.jsonPath(objectArray, jsonPathQuery);
        }

        return objectArray;
    }
}
