import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem

MainView {
    id: mainView
    // objectName for functional testing purposes (autopilot-qt5)
    objectName: "mainView"
    
    // Note! applicationName needs to match the .desktop filename 
    applicationName: "stackbrowser"
    
    automaticOrientation: true
    
    width: units.gu(50)
    height: units.gu(75)

    PageStack {
        id: pageStack
        Component.onCompleted: {
            push(home)
        }

        Page {
            id: home
            visible: false
            title: "StackBrowser"

            ListView {
                id: stackList
                anchors.fill: parent
                model: StackListModel {
                     id: allStackFeed
                     path: "sites"
                     query: "$.items[?(@.site_type=='main_site')]"
                     args: "pagesize=200"
                 }

                delegate: ListItem.Subtitled {
                    id: stackItemDelegate
                    text: model.name
                    subText: model.audience
                    icon: Qt.resolvedUrl(model.icon_url)
                    progression: true
                    onClicked: {
                        browser.stack = model
                        pageStack.push(browser)
                    }
                }
            }
        }

        Page {
            id: browser
            visible: false
            property var stack: undefined

            onStackChanged: {
                if (stack) {
                    browser.title = stack.name
                    stackView.logo = stack.logo_url
                    stackView.site = stack.api_site_parameter
                    stackView.link = stack.site_url
                    stackView.reload()
                }
            }

            tools: ToolbarItems {
                ToolbarButton {
                    iconSource: Qt.resolvedUrl("graphics/go-to.svg")
                    text: i18n.tr("Open site")

                    onTriggered: {
                        Qt.openUrlExternally(stackView.link)
                    }
                }
            }

            Label {
                id: listViewFooter
                text: 'Load More...'
                fontSize: "large"
                anchors.bottom: parent.bottom
                x: (parent.width / 2) - (width / 2)
                visible: false
            }

            StackBrowserListView {
                id: stackView
                property var logo: undefined
                property var site: ''
                property var link: ''

                function reload() {
                    if (stackFeed){
                        stackFeed.reload()
                    }
                }
            }
        }

        Page {
            id: questionViewer
            visible: false
            title: browser.title
            property var question: undefined
            property var link: undefined

            tools: ToolbarItems {
                ToolbarButton {
                    iconSource: Qt.resolvedUrl("graphics/go-to.svg")
                    text: i18n.tr("Open site")

                    onTriggered: {
                        Qt.openUrlExternally(questionViewer.link)
                    }
                }
            }

            onQuestionChanged: {
                if (question) {
                    questionView.reload()
                }
            }

            QuestionView {
                id: questionView
                property var logo: undefined
                property var site: ''

                function reload() {
                    if (questionFeed){
                        questionFeed.reload()
                    }
                }
            }

        }
    }
}
